.. Copyright (C) 2015-2019 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2019      Tasos Alvas <tasos.alvas@qwertyuiopia.com>
.. Copyright (C) 2015-2019 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _cmd_debops-init:

The :command:`debops-init` command
==================================

Creates a project for you at the path you specify. After running this script
you should check out :command:`ansible/inventory/hosts` relative to your project path.

Example commands:

.. code:: shell

    debops-init ~/myproject
